@@ -87,7 +87,7 @@ WWW::Kickstarter::Data::Project - Kickstarter project data
    $ks->login($email, $password);
 
    my $iter = $ks->projects_ending_soon();
-   while (my ($project) = $iter->()) {
+   while (my ($project) = $iter->get()) {
       print($project->name, "\n");
    }
 
